<?php
// -=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
// Blocking direct access to plugin      -=
// -=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
defined('ABSPATH') or die('Are you crazy!');

/**
 * LOAD THE BASE CLASS
 * ==============================================================
 * http://codex.wordpress.org/Class_Reference/WP_List_Table
 * http://wordpress.org/extend/plugins/custom-list-table-example/
 */
if ( ! class_exists('WP_List_Table') ) {
    require_once( ABSPATH . 'wp-admin/includes/class-wp-list-table.php' );
}

/************************** CREATE A PACKAGE CLASS *****************************
 *******************************************************************************
 * Create a new list table package that extends the core WP_List_Table class.
 * WP_List_Table contains most of the framework for generating the table, but we
 * need to define and override some methods so that our data can be displayed
 * exactly the way we need it to be.
 * To display this example on a page, you will first need to instantiate the class,
 * then call $yourInstance->prepare_items() to handle any data manipulation, then
 * finally call $yourInstance->display() to render the table to the page.
 */
class pixelstat_List_Table extends WP_List_Table {

    function __construct(){
        global $status, $page;    
        //Set parent defaults
        parent::__construct( array(
            'singular'  => 'list',     // singular name of the listed records
            'plural'    => 'lists',    // plural name of the listed records
            'ajax'      => false       // does this table support ajax?
        ) );
    }
	
    /**
     * [REQUIRED] this is a default column renderer
     *
     * @param $item - row (key, value array)
     * @param $column_name - string (key)
     * @return HTML
     */
    function column_default($item, $column_name) {
        return $item[$column_name];
    }

    /**
     * [OPTIONAL] this is a default column renderer
     *
     * @param $item - row (key, value array)
     * @param $column_name - string (key)
     * @return HTML
     */
    function column_date($item) {
		return pixelstat_convert_date($item['date'], 'FRT');
    }
	
	
	function column_order_id($item) {
        // Build row actions
        // links going to /admin.php?page=[your_plugin_page][&other_params]
        // notice how we used $_REQUEST['page'], so action will be done on current page
        // also notice how we use $this->_args['singular'] so in this example it will be something like &person=2
        $actions = array(
			//''        => '<span style="color:silver">ID: '.$item['id'].'</span>',
            'delete'  => sprintf('<a onclick="return pixelstat_confirm_delete(\''.__('this entry', PIXELSTAT_ID_LANGUAGES).'\');" href="?page=%s&action=%s&id=%s">%s</a>', $_REQUEST['page'], 'delete', $item['id'], __('Delete this selection', PIXELSTAT_ID_LANGUAGES)),
            'show'    => sprintf('<a href="%s" target="_blank">%s</a>', get_permalink($item['product_id']), __('Voir le produit', ILIST_ID_LANGUAGES)),
			'c'       => sprintf('<a href="%s" target="_blank">%s</a>', admin_url( 'post.php?post=' . $item['order_id'] . '&action=edit' ), __('Voir la commande', ILIST_ID_LANGUAGES)),
        );

        // Return the title contents
        return sprintf('%1$s %2$s',
            /*$1%s*/ $item['order_id'],
            /*$2%s*/ $this->row_actions($actions)
        );
	}
	
    /**
     * [OPTIONAL] this is example, how to render column with actions,
     * when you hover row "Edit | Delete" links showed
     *
     * @param $item - row (key, value array)
     * @return HTML
     */
    function column_product_id($item) {
		// Get product infos
		$product    = (wc_get_product( $item['product_id'] ));
		$product_id = "<br><span style='font-style: italic; color: grey;'>ID: " . $item['product_id'] . "</span>";
        return ($product) ? $product->get_title() . $product_id : __('Unknown', PIXELSTAT_ID_LANGUAGES) . $product_id;
    }
	
    /**
     * [OPTIONAL] this is a default column renderer
     *
     * @param $item - row (key, value array)
     * @param $column_name - string (key)
     * @return HTML
     */
    function column_status($item) {
        return ($item['status']) ? '<i class="fa fa-check-square-o" style="color: green;" aria-hidden="true"></i>' : '<i class="fa fa-circle" style="color: red;" aria-hidden="true"></i>';
    }
	
    /**
     * [REQUIRED] this is how checkbox column renders
     *
     * @param $item - row (key, value array)
     * @return HTML
     */
    function column_cb($item) {
        return sprintf(
            '<input type="checkbox" name="id[]" value="%s" />',
            $item['id']
        );
    }
	
    /**
     * [REQUIRED] This method return columns to display in table
     * you can skip columns that you do not want to show
     * like content, or description
     *
     * @return array
     */
    function get_columns() {
        $columns = array(
            'cb'         => '<input type="checkbox" />', //Render a checkbox instead of text
            'date'       => __('Date', PIXELSTAT_ID_LANGUAGES),
            'order_id'   => __('Order', PIXELSTAT_ID_LANGUAGES),
            'product_id' => __('Product', PIXELSTAT_ID_LANGUAGES),
            'ip'         => __('IP', PIXELSTAT_ID_LANGUAGES),
            //'pixel'      => __('Pixel', PIXELSTAT_ID_LANGUAGES),
            'status'     => __('Paid', PIXELSTAT_ID_LANGUAGES),
        );
        return $columns;
    }
	
    /**
     * [OPTIONAL] This method return columns that may be used to sort table
     * all strings in array - is column names
     * notice that true on name column means that its default sort
     *
     * @return array
     */
    function get_sortable_columns() {
        $sortable_columns = array(
            'date'       => array('date', true),   //true means it's already sorted
            'order_id'   => array('order_id', false),  //true means it's already sorted
            'product_id' => array('product_id', false),  //true means it's already sorted
            'ip'         => array('ip', false),
            //'pixel'      => array('pixel', false),
            'status'     => array('status', false),
        );
        return $sortable_columns;
    }
	
	/**
	 * Displays the search box.
	 *
	 * @since 3.1.0
	 * @access public
	 *
	 * @param string $text     The 'submit' button label.
	 * @param string $input_id ID attribute value for the search input field.
	 */
	public function search_box( $text, $input_id ) {
		if ( empty( $_REQUEST['s'] ) && !$this->has_items() )
			return;

		$input_id = $input_id . '-search-input';

		if ( ! empty( $_REQUEST['orderby'] ) )
			echo '<input type="hidden" name="orderby" value="' . esc_attr( $_REQUEST['orderby'] ) . '" />';
		if ( ! empty( $_REQUEST['order'] ) )
			echo '<input type="hidden" name="order" value="' . esc_attr( $_REQUEST['order'] ) . '" />';
		if ( ! empty( $_REQUEST['post_mime_type'] ) )
			echo '<input type="hidden" name="post_mime_type" value="' . esc_attr( $_REQUEST['post_mime_type'] ) . '" />';
		if ( ! empty( $_REQUEST['detached'] ) )
			echo '<input type="hidden" name="detached" value="' . esc_attr( $_REQUEST['detached'] ) . '" />';
?>
<p class="search-box">
	<label class="screen-reader-text" for="<?php echo esc_attr( $input_id ); ?>"><?php echo $text; ?>:</label>
	<input type="search" id="<?php echo esc_attr( $input_id ); ?>" name="s" value="<?php _admin_search_query(); ?>" />
	<?php submit_button( $text, '', '', false, array( 'id' => 'search-submit' ) ); ?>
</p>
<?php
	}

	
    /**
     * [OPTIONAL] Return array of bult actions if has any
     *
     * @return array
     */
    function get_bulk_actions() {
        $actions = array(
            'delete'     => __('Delete', PIXELSTAT_ID_LANGUAGES),
            'delete_all' => __('Delete All', PIXELSTAT_ID_LANGUAGES),
        );
        return $actions;
    }
	
    /**
     * [OPTIONAL] This method processes bulk actions
     * it can be outside of class
     * it can not use wp_redirect coz there is output already
     * in this example we are processing delete action
     * message about successful deletion will be shown on page in next part
     */
    function process_bulk_action() {
        global $wpdb, $plugin_table_name;
        $table_name_list = $wpdb->prefix . $plugin_table_name; // do not forget about tables prefix
		
        if ('delete' === $this->current_action()) {
            $ids = isset($_REQUEST['id']) ? $_REQUEST['id'] : array();
            if (is_array($ids)) $ids = implode(',', $ids);

            if (!empty($ids)) {
                $wpdb->query("DELETE FROM $table_name_list WHERE id IN($ids)");
            }
        }
		
        if ('delete_all' === $this->current_action()) {
            $wpdb->query("DELETE FROM $table_name_list");
        }
		
    }
	
	/**
	 * Get number of items to display on a single page
	 *
	 * @since 3.1.0
	 * @access protected
	 *
	 * @param string $option
	 * @param int    $default
	 * @return int
	 */
	protected function get_items_per_page( $option, $default = 20 ) {
		$per_page = (int) get_user_option( $option );
		if ( empty( $per_page ) || $per_page < 1 )
			$per_page = $default;

		/**
		 * Filters the number of items to be displayed on each page of the list table.
		 *
		 * The dynamic hook name, $option, refers to the `per_page` option depending
		 * on the type of list table in use. Possible values include: 'edit_comments_per_page',
		 * 'sites_network_per_page', 'site_themes_network_per_page', 'themes_network_per_page',
		 * 'users_network_per_page', 'edit_post_per_page', 'edit_page_per_page',
		 * 'edit_{$post_type}_per_page', etc.
		 *
		 * @since 2.9.0
		 *
		 * @param int $per_page Number of items to be displayed. Default 20.
		 */
		return (int) apply_filters( "{$option}", $per_page );
	}
	
    /**
     * [REQUIRED] This is the most important method
     *
     * It will get rows from database and prepare them to be showed in table
     */
    function prepare_items($search = NULL) {
        global $wpdb, $plugin_table_name;
        $table_name = $wpdb->prefix . $plugin_table_name; // do not forget about tables prefix

        // How much records will be shown per page (option screen)
		$screen   = get_current_screen();  // Get screen option
		$user     = get_current_user_id(); // Get current user ID
		$option   = $screen->get_option('per_page', 'option');
		$per_page = get_user_meta($user, $option, true);
		if ( empty ( $per_page) || $per_page < 1 ) {
			$per_page = $screen->get_option( 'per_page', 'default' );
		}
		
        // here we configure table headers, defined in our methods
        $columns  = $this->get_columns();
        $hidden   = array();
        $sortable = $this->get_sortable_columns();
        $this->_column_headers = array($columns, $hidden, $sortable);

        // [OPTIONAL] process bulk action if any
        $this->process_bulk_action();

        // will be used in pagination settings
        $total_items = $wpdb->get_var("SELECT COUNT(id) FROM $table_name");

        // prepare query params, as usual current page, order by and order direction
		$paged = !empty($_GET["paged"]) ? intval($_GET["paged"]) : '';		
		if (empty($paged) || !is_numeric($paged) || $paged <= 0) $paged = 1;
        $orderby = (isset($_REQUEST['orderby']) && in_array($_REQUEST['orderby'], array_keys($this->get_sortable_columns()))) ? $_REQUEST['orderby'] : 'date';
        $order = (isset($_REQUEST['order']) && in_array($_REQUEST['order'], array('asc', 'desc'))) ? $_REQUEST['order'] : 'desc';

		// If the value is not NULL, do a search for it
		if ( $search != NULL ) {
			// Trim Search Term
			$search = trim($search);
			/* Notice how you can search multiple columns for your search term easily, and return one data set */
			$this->items = $wpdb->get_results($wpdb->prepare("SELECT * FROM $table_name WHERE `name` LIKE '%%%s%%' OR `firstname` LIKE '%%%s%%' OR `lastname` LIKE '%%%s%%' OR `email` LIKE '%%%s%%' ORDER BY $orderby $order", $search, $search, $search, $search), ARRAY_A);
		} else {
			// [REQUIRED] define $items array
			// notice that last argument is ARRAY_A, so we will retrieve array
			if ($paged > 1)
				$this->items = $wpdb->get_results($wpdb->prepare("SELECT * FROM $table_name ORDER BY $orderby $order LIMIT %d,%d", $per_page, $paged), ARRAY_A);
			else
				$this->items = $wpdb->get_results($wpdb->prepare("SELECT * FROM $table_name ORDER BY $orderby $order LIMIT %d", $per_page), ARRAY_A);
		}
		
        // [REQUIRED] configure pagination
        $this->set_pagination_args(array(
            'total_items' => $total_items, // total items defined above
            'per_page'    => $per_page,    // per page constant defined at top of method
            'total_pages' => ceil($total_items / $per_page) // calculate pages count
        ));
		
    }
	
}

/**
 * Display the products number by list
 * 
 * @param string $list_id ID attribute value.
 */
function pixelstat_get_nb_products_by_list($list_id) {
	global $wpdb;
	$table_name = $wpdb->prefix . $plugin_table_name_data; // do not forget about tables prefix
	// Initialization
	$rowcount = 0;
	// Check if list ID
	if ($list_id > 0) {
		$rowcount = $wpdb->get_var("SELECT COUNT(list_id) FROM $table_name WHERE list_id = '$list_id'");
	}
	
	return $rowcount;
}

/**
 * http://codex.wordpress.org/Data_Validation
 * http://codex.wordpress.org/Function_Reference/selected
 *
 * Form page handler checks is there some data posted and tries to save it
 * Also it renders basic wrapper in which we are callin meta box render
 */
function pixelstat_list_form_page_handler() {
//$action = $_REQUEST['action'];
//switch($action) {
//	case "edit":
		global $wpdb, $plugin_table_name;
		$table_name = $wpdb->prefix . $plugin_table_name; // do not forget about tables prefix
	
		// Initialization
		$message = '';
		$notice  = '';
	
		// this is default $item which will be used for new records
		$default = array(
			'id'          => 0,
			'user_id'     => 0,
			'date'        => null,
			'name'        => '',
			'description' => null,
			'firstname'   => '',
			'lastname'    => '',
			'email'       => '',
			'keyaccess'   => '',
			'active'      => 1,
		);
	
		// here we are verifying does this request is post back and have correct nonce
		if ( isset($_REQUEST['nonce']) && wp_verify_nonce($_REQUEST['nonce'], basename(__FILE__))) {
			// combine our default item with request params
			$item = shortcode_atts($default, $_REQUEST);
			// validate data, and if all ok save item to database
			// if id is zero insert otherwise update
			$item_valid = pixelstat_validate_list($item);
			if ($item_valid === true) {
				if ($item['id'] == 0) {
					$result = $wpdb->insert($table_name, $item);
					$item['id'] = $wpdb->insert_id;
					if ($result) {
						$message = __('List saved successfully', PIXELSTAT_ID_LANGUAGES);
					} else {
						$notice = __('ERROR when saving list', PIXELSTAT_ID_LANGUAGES);
					}
				} else {
					$result = $wpdb->update($table_name, stripslashes_deep($item), array('id' => $item['id']));
					if ($result) {
						$message = __('List updated successfully', PIXELSTAT_ID_LANGUAGES);
					} else {
						if (_ILIST_DEBUG) {
							$wpdb->show_errors();
							$wpdb->print_error();
						}
						$notice = __('ERROR when editing list (no information changed)', PIXELSTAT_ID_LANGUAGES);
					}
				}
			} else {
				// if $item_valid not true it contains error message(s)
				$notice = $item_valid;
			}
		}
		else {
			// if this is not post back we load item to edit or give new one to create
			$item = $default;
			if (isset($_REQUEST['id'])) {
				$item = $wpdb->get_row($wpdb->prepare("SELECT * FROM $table_name WHERE id = %d", $_REQUEST['id']), ARRAY_A);
				if (!$item) {
					$item = $default;
					$notice = __('List not found', PIXELSTAT_ID_LANGUAGES);
				}
			}
		}
	
		// here we adding our custom meta box
		$pixelstat_meta_box_edit_list = __('Edit list', PIXELSTAT_ID_LANGUAGES);
		add_meta_box('pixelstat_form_meta_box', $pixelstat_meta_box_edit_list, 'pixelstat_list_form_meta_box_handler', 'ilist', 'normal', 'default');
	
		?>

	<div class="wrap page_ilist">
		<div class="icon32 icon32-posts-post" id="icon-edit"><br></div>
		<h2>
			<?php _e('List :: ' .$item['name'], PIXELSTAT_ID_LANGUAGES); ?>
			&nbsp;
			<a class="add-new-h2" href="<?php echo get_admin_url(get_current_blog_id(), 'admin.php?page=pixelstat_list');?>">
				<?php _e('Back to lists', PIXELSTAT_ID_LANGUAGES)?>
			</a>
			&nbsp;
			<a class="add-new-h2" href="<?php echo get_admin_url(get_current_blog_id(), 'admin.php?page=pixelstat_products&id=' . $item['id']);?>">
				<?php _e('See products', PIXELSTAT_ID_LANGUAGES)?>
			</a>
		</h2>
	
		<?php if (!empty($notice)): ?>
		<div id="notice" class="error"><p><?php echo $notice ?></p></div>
		<?php endif;?>
		<?php if (!empty($message)): ?>
		<div id="message" class="updated"><p><?php echo $message ?></p></div>
		<?php endif;?>
	
		<form id="form" method="POST">
			<input type="hidden" name="nonce" value="<?php echo wp_create_nonce(basename(__FILE__))?>"/>
			<?php /* NOTICE: here we storing id to determine will be item added or updated */ ?>
			<input type="hidden" name="id" value="<?php echo $item['id'] ?>"/>
			<input type="hidden" name="date" value="<?php echo $item['date'] ?>"/>
			<input type="hidden" name="user_id" value="<?php echo $item['user_id'] ?>"/>
			<input type="hidden" name="keyaccess" value="<?php echo $item['keyaccess'] ?>"/>
	
			<div class="metabox-holder" id="poststuff">
				<div id="post-body">
					<div id="post-body-content" class="post-body-ilist">
						<?php /* And here we call our custom meta box */ ?>
						<?php do_meta_boxes('ilist', 'normal', $item); ?>
						<input type="submit" value="<?php _e('Save', PIXELSTAT_ID_LANGUAGES)?>" id="submit" class="button-primary" name="submit">
					</div>
				</div>
			</div>
		</form>
	</div>
	<?php
	//break;
//}
}

/**
 * This function renders our custom meta box
 * $item is row
 *
 * @param $item
 */
function pixelstat_list_form_meta_box_handler($item) {
    ?>

<table cellspacing="2" cellpadding="5" style="width: 100%;" class="form-table">
    <tbody>
    <tr class="form-field">
        <th valign="top" scope="row">
            <label for="active"><?php _e('Active', PIXELSTAT_ID_LANGUAGES)?></label>
        </th>
        <td>
			<input type="radio" name="active" value="1" <?php if ($item['active'] == '1') echo 'checked="checked"' ?> />&nbsp;<?php _e('YES', PIXELSTAT_ID_LANGUAGES)?>
			&nbsp;&nbsp;&nbsp;
			<input type="radio" name="active" value="0" <?php if ($item['active'] == '0') echo 'checked="checked"' ?> />&nbsp;<?php _e('NO', PIXELSTAT_ID_LANGUAGES)?>
        </td>
    </tr>
    <tr class="form-field">
        <th valign="top" scope="row">
            <label for="name"><?php _e('List name', PIXELSTAT_ID_LANGUAGES)?> *</label>
        </th>
        <td>
            <input id="name" name="name" type="text" style="width: 95%" value="<?php echo esc_attr($item['name'])?>"
                   size="50" class="code" placeholder="<?php _e('List name', PIXELSTAT_ID_LANGUAGES)?>" required>
        </td>
    </tr>
    <tr class="form-field">
        <th valign="top" scope="row">
            <label for="firstname"><?php _e('Firstname', PIXELSTAT_ID_LANGUAGES)?> *</label>
        </th>
        <td>
            <input id="firstname" name="firstname" type="text" style="width: 95%" value="<?php echo esc_attr($item['firstname'])?>"
                   size="50" class="code" placeholder="<?php _e('Firstname', PIXELSTAT_ID_LANGUAGES)?>" required>
        </td>
    </tr>
    <tr class="form-field">
        <th valign="top" scope="row">
            <label for="lastname"><?php _e('Lastname', PIXELSTAT_ID_LANGUAGES)?> *</label>
        </th>
        <td>
            <input id="lastname" name="lastname" type="text" style="width: 95%" value="<?php echo esc_attr($item['lastname'])?>"
                   size="50" class="code" placeholder="<?php _e('Lastname', PIXELSTAT_ID_LANGUAGES)?>" required>
        </td>
    </tr>
    <tr class="form-field">
        <th valign="top" scope="row">
            <label for="email"><?php _e('Email', PIXELSTAT_ID_LANGUAGES)?> *</label>
        </th>
        <td>
            <input id="email" name="email" type="email" style="width: 95%" value="<?php echo esc_attr($item['email'])?>"
                   size="50" class="code" placeholder="<?php _e('Your Email', PIXELSTAT_ID_LANGUAGES)?>" required>
        </td>
    </tr>
    <tr class="form-field">
        <th valign="top" scope="row">
            <label for="description"><?php _e('Description', PIXELSTAT_ID_LANGUAGES)?></label>
        </th>
        <td>
            <textarea id="description" name="description" style="width: 95%" rows="5"
                   class="code" placeholder="<?php _e('Description', PIXELSTAT_ID_LANGUAGES)?>"><?php echo stripslashes_from_strings_only($item['description'])?></textarea>
        </td>
    </tr>
    </tbody>
</table>
<?php
}

/**
 * Simple function that validates data and retrieve bool on success
 * and error message(s) on error
 *
 * @param $item
 * @return bool|string
 */
function pixelstat_validate_list($item) {
    $messages = array();

    if (empty($item['name'])) $messages[] = __('List name is required', PIXELSTAT_ID_LANGUAGES);
    if (empty($item['firstname'])) $messages[] = __('Firstname is required', PIXELSTAT_ID_LANGUAGES);
    if (empty($item['lastname'])) $messages[] = __('Lastname is required', PIXELSTAT_ID_LANGUAGES);
    if (empty($item['email'])) $messages[] = __('Email is required', PIXELSTAT_ID_LANGUAGES);
    if (!empty($item['email']) && !is_email($item['email'])) $messages[] = __('The email has an incorrect format', PIXELSTAT_ID_LANGUAGES);

    if (empty($messages)) return true;
    return implode('<br />', $messages);
}

?>