<?php
// -=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
// Blocking direct access to plugin      -=
// -=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
defined('ABSPATH') or die('Are you crazy!');

// -=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
// -=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=

/**
 * Show date ISO in various format (Pixel Stat)
 * This method return string to display
 *
 * @param	$date		Date ISO Format from MySQL
 * @param	$format		Format to return (ISO, US, UST, FR, FRT, FRH, YEAR)
 *
 * @return converted string
 */
if (!function_exists("pixelstat_convert_date")) {
	function pixelstat_convert_date($date, $format = 'ISO') {
		switch(strtoupper($format)) {
			// Format ISO (AAAA-MM-DD)
			default: return strftime("%F", strtotime($date)); break;
			// Format US (MM-DD-AAAA)
			case "US": return strftime("%m/%d/%Y", strtotime($date)); break;
			// Format US (MM-DD-AAAA HH:mm:ss)
			case "UST": return strftime("%m/%d/%Y %T", strtotime($date)); break;
			// Format FR (DD-MM-AAAA)
			case "FR": return strftime("%d/%m/%Y", strtotime($date)); break;
			// Format FR (DD-MM-AAAA HH:mm:ss) with time
			case "FRT": return strftime("%d-%m-%Y %T", strtotime($date)); break;
			// Format FRH (DD MM AAAA) Human readable
			case "FRH": return strftime("%e %B %Y", strtotime($date)); break;
			// Year (AAAA)
			case "YEAR": return strftime("%Y", strtotime($date)); break;
		}
	}
}

/**
 * Get all lists from Database (Pixel Stat)
 * This method return Array to display
 *
 * @param	$where	Where SQL clause
 *
 * @return array
 */
if (!function_exists("pixelstat_get_lists_limit")) {
	function pixelstat_get_lists_limit($limit = 5) {
		global $wpdb, $plugin_table_name;
		
		// --- Initialize
		$all_lists       = false;
		$table_name_list = $wpdb->prefix . $plugin_table_name;
		// Get all list from user_id
		$sql_request =
			"SELECT t1.id, t1.date, t1.name, count(t2.id) AS count_products
			 FROM $table_name_list AS t1
			 LEFT JOIN $table_name_data AS t2 ON (t1.id = t2.list_id)
			 WHERE t1.active = '1'
			 GROUP BY t1.id, t1.date, t1.name
			 LIMIT $limit";
		$all_lists = $wpdb->get_results( $sql_request );

		return $all_lists;
	}
}

/**
* Return a string to truncate
* @param string $string
* @param int $max
* @param string $replacement
* @return string truncated
*/
if (!function_exists("pixelstat_truncate")) {
	function pixelstat_truncate($string, $max = 20, $replacement = '') {
		if (strlen($string) <= $max) {
			return $string;
		}
		$leave = $max - strlen ($replacement);
		return substr_replace($string, $replacement, $leave);
	}
}

/**
* Searches text for unwanted tags and removes them
* @param string $text String to purify
* @return string $text The purified text
*/
if (!function_exists("pixelstat_stop_XSS")) {
	function pixelstat_stop_XSS($text) {
		if (!is_array($text)) {
			$text = preg_replace("/\(\)/si", "", $text);
			$text = strip_tags($text);
			$text = str_replace(array("\"",">","<","\\"), "", $text);
		} else {
			foreach($text as $k=>$t) {
				if (is_array($t)) {
					StopXSS($t);
				} else {
					$t = preg_replace("/\(\)/si", "", $t);
					$t = strip_tags($t);
					$t = str_replace(array("\"",">","<","\\"), "", $t);
					$text[$k] = $t;
				}
			}
		}
		return $text;
	}
}

/**
 * Check whether URL is HTTPS/HTTP
 * @return boolean [description]
 */
if (!function_exists("pixelstat_is_secure")) {
	function pixelstat_is_secure() {
		if (
			( ! empty($_SERVER['HTTPS']) && $_SERVER['HTTPS'] !== 'off')
			|| ( ! empty($_SERVER['HTTP_X_FORWARDED_PROTO']) && $_SERVER['HTTP_X_FORWARDED_PROTO'] == 'https')
			|| ( ! empty($_SERVER['HTTP_X_FORWARDED_SSL']) && $_SERVER['HTTP_X_FORWARDED_SSL'] == 'on')
			|| (isset($_SERVER['SERVER_PORT']) && $_SERVER['SERVER_PORT'] == 443)
			|| (isset($_SERVER['HTTP_X_FORWARDED_PORT']) && $_SERVER['HTTP_X_FORWARDED_PORT'] == 443)
			|| (isset($_SERVER['REQUEST_SCHEME']) && $_SERVER['REQUEST_SCHEME'] == 'https')
		) {
			return true;
		} else {
			return false;
		}
	}
}

?>