<?php
/**
 * Ilist
 *
 * @package     Pixel stat
 * @author      INFORMATUX (Patrice BOUTHIER)
 * @copyright   2020 INFORMATUX
 * @license     GPL-3.0+
 *
 * @naissance
 * Plugin Name: Pixel stat
 * Description: Gestion de pixel Google Tag Manager, Facebook et autres codes de tracking pour WooCommerce
 * Version:     1.0.3
 * Author:      Patrice BOUTHIER
 * Author URI:  https://dev.informatux.com
 * Text Domain: pixelstat
 * License:     GPL-3.0+
 * License URI: http://www.gnu.org/licenses/gpl-3.0.txt
 */

// -=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
// Blocking direct access to plugin      -=
// -=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
defined('ABSPATH') or die('Are you crazy!');

// -=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
// Define constants                      -=
// -=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
defined('PIXELSTAT_PATH') or define('PIXELSTAT_PATH', plugin_dir_path(__FILE__));
defined('PIXELSTAT_URL') or define('PIXELSTAT_URL', plugin_dir_url(__FILE__));
defined('PIXELSTAT_BASE') or define('PIXELSTAT_BASE', plugin_basename(__FILE__));
defined('PIXELSTAT_ID') or define('PIXELSTAT_ID', 'pixelstat');
defined('PIXELSTAT_ID_LANGUAGES') or define('PIXELSTAT_ID_LANGUAGES', 'pixelstat-translate');
defined('PIXELSTAT_COOKIE') or define('PIXELSTAT_COOKIE', 'pixelstat_cookie');
defined('PIXELSTAT_VERSION') or define('PIXELSTAT_VERSION', '1.0.1');
defined('PIXELSTAT_CRON_SCHEDULE') or define('PIXELSTAT_CRON_SCHEDULE', '1min');

// -=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
// Load plugin translations              -=
// -=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
add_action( 'plugins_loaded', 'pixelstat_translate_load_textdomain', 1 );
if ( ! function_exists( 'pixelstat_translate_load_textdomain' ) ) {
	function pixelstat_translate_load_textdomain() {
		$path = basename( dirname( __FILE__ ) ) . '/languages/';
		load_plugin_textdomain( PIXELSTAT_ID_LANGUAGES, false, $path );
	}
}

defined('PIXELSTAT_NAME') or define('PIXELSTAT_NAME', 'Pixel stat');

// -=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
// Load plugin files                     -=
// -=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
if ( ! function_exists( 'is_plugin_active' ) )
    include_once( ABSPATH . 'wp-admin/includes/plugin.php' );

// -=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
// Include Titan Framework               -=
// -=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
$titan_check_framework_install = 'titan-framework/titan-framework.php';
// --- Check if plugin titan framework is installed
if (is_plugin_active($titan_check_framework_install)) {
	require_once(WP_CONTENT_DIR . '/plugins/titan-framework/titan-framework-embedder.php');
} else {
	require_once(PIXELSTAT_PATH . 'lib/titan-framework/titan-framework-embedder.php');
}

// -=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
// Initialize plugin SQL Debug Mode      -=
// -=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
defined('_PIXELSTAT_DEBUG') or define('_PIXELSTAT_DEBUG', false);

// -=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
// Initialize plugin Files               -=
// -=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
$pixelstatClasses = ['lists', 'cron'];
foreach ($pixelstatClasses as $pixelstatClass) {
	$class = PIXELSTAT_PATH . 'class' . DIRECTORY_SEPARATOR . PIXELSTAT_ID . '-class-' . $pixelstatClass . '.php';
    if (file_exists($class)) require_once($class);
}
$pixelstatFiles = ['system', 'interface', 'style', 'functions'];
foreach ($pixelstatFiles as $pixelstatFile) {
	$file = PIXELSTAT_PATH . PIXELSTAT_ID . '-' . $pixelstatFile . '.php';
    if (file_exists($file)) require_once($file);
}

// -=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
//         Pixel Stat Meta links         -=
//            in plugins page            -=
// -=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
if ( ! function_exists( 'pixelstat_plugin_row_meta' ) ) {
    function pixelstat_plugin_row_meta( $links, $file ) {
        if (strpos($file, PIXELSTAT_BASE) !== false) {
            $new_links = array(
                'donate' => '<a href="https://paypal.me/informatux27/10" target="_blank"><span class="dashicons dashicons-star-filled"></span>' . __( 'Donate', PIXELSTAT_ID_LANGUAGES ) . '</a>',
                'cv' => '<a href="https://cv.informatux.com/" target="_blank"><span class="dashicons dashicons-id-alt"></span>' . __( 'About', PIXELSTAT_ID_LANGUAGES ) . '</a>'
            );
            
            $links = array_merge($links, $new_links);
        }
        
        return $links;
    }
}
add_filter( 'plugin_row_meta', 'pixelstat_plugin_row_meta', 10, 2 );
// -=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=


// -=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
//        Pixel Stat Get Infos           -=
// -=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
if ( ! function_exists( 'get_plugin_data' ) ) {
	require_once ABSPATH . 'wp-admin/includes/plugin.php';
}

if ( ! function_exists( 'pixelstat_get_version' ) ) {
    function pixelstat_get_version( $pixelstat_infos = 'Version' ) {
    
        /* *************************************************************************************
         *
         * 'Name' - Name of the plugin, must be unique.
         * 'Title' - Title of the plugin and the link to the plugin's web site.
         * 'Description' - Description of what the plugin does and/or notes from the author.
         * 'Author' - The author's name
         * 'AuthorURI' - The authors web site address.
         * 'Version' - The plugin version number.
         * 'PluginURI' - Plugin web site address.
         * 'TextDomain' - Plugin's text domain for localization.
         * 'DomainPath' - Plugin's relative directory path to .mo files.
         * 'Network' - Boolean. Whether the plugin can only be activated network wide.
         *
         * ********************************************************************************** */
    
        $plugin_data = get_plugin_data( __FILE__ );
        $plugin_version = $plugin_data[ "$pixelstat_infos" ];
        return $plugin_version;
    }
}
// -=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=

// ----------------------------------------------------------------------
// ----------------------------------------------------------------------
// ----------------------------------------------------------------------
/**
 * New schedule times via cron_schedules
 */
add_filter('cron_schedules','pixelstat_cron_schedules');
function pixelstat_cron_schedules($schedules){
    if(!isset($schedules["1min"])){
        $schedules["1min"] = array(
            'interval' => 1*60,
            'display' => __('Once every 1 minute'));
    }
    if(!isset($schedules["2min"])){
        $schedules["2min"] = array(
            'interval' => 2*60,
            'display' => __('Once every 2 minutes'));
    }
    if(!isset($schedules["5min"])){
        $schedules["5min"] = array(
            'interval' => 5*60,
            'display' => __('Once every 5 minutes'));
    }
    if(!isset($schedules["10min"])){
        $schedules["10min"] = array(
            'interval' => 10*60,
            'display' => __('Once every 10 minutes'));
    }
    if(!isset($schedules["30min"])){
        $schedules["30min"] = array(
            'interval' => 30*60,
            'display' => __('Once every 30 minutes'));
    }
    return $schedules;
}
/**
* Register the scheduled jobs at plugin activation
* @Add Scheduled Jobs
*/
register_activation_hook ( __FILE__, 'pixelstat_scheduled_jobs_activate' );
function pixelstat_scheduled_jobs_activate() {
	wp_schedule_event( time(), PIXELSTAT_CRON_SCHEDULE, 'pixelstat_check_status_order' );
}
// --- Add Action Pixel Stat Do Cron
add_action( 'pixelstat_check_status_order', 'pixelstat_do_cron' );
// ----------------------------------------------------------------------
/**
 * Check if cron job exists
 * @Check cron after WP Update or others
 */
if ( !wp_get_schedule( 'pixelstat_check_status_order' )) {
	wp_schedule_event( time(), PIXELSTAT_CRON_SCHEDULE, 'pixelstat_check_status_order' );
}
// ----------------------------------------------------------------------
// ----------------------------------------------------------------------
// ----------------------------------------------------------------------
// --- Add action when payment process is complete
add_action( 'woocommerce_checkout_order_processed', 'pixelstat_wc_checkout_order', 10, 3 );
/**
 * Get order_id before payment
 * And insert Infos for each Product Pixel Stat in DB
 */
function pixelstat_wc_checkout_order( $order_id ) {
	global $wpdb, $plugin_table_name;
	// --- Initialize
	$table_name_data = $wpdb->prefix . $plugin_table_name;
	
	if ( ! $order_id ) {
	  return;
	}
	// Get order infos
	$order    = new WC_Order( $order_id );
	// Initialize
	$order_ip = $_SERVER['HTTP_CLIENT_IP'] ? $_SERVER['HTTP_CLIENT_IP'] : ($_SERVER['HTTP_X_FORWARDE‌​D_FOR'] ? $_SERVER['HTTP_X_FORWARDED_FOR'] : $_SERVER['REMOTE_ADDR']);
	// Insert all products in DB
	// Iterating through each WC_Order_Item_Product objects
	foreach ($order->get_items() as $item_key => $item_values) {
		## Using WC_Order_Item methods ##	
		// Item ID is directly accessible from the $item_key in the foreach loop or
		//$item_id = $item_values->get_id();
		## Using WC_Order_Item_Product methods ##	
		//$item_name = $item_values->get_name(); // Name of the product
		//$item_type = $item_values->get_type(); // Type of the order item ("line_item")
		//
		$product_id = $item_values->get_product_id(); // the Product id
		//$wc_product = $item_values->get_product(); // the WC_Product object
		## Access Order Items data properties (in an array of values) ##
		//$item_data = $item_values->get_data();
		//
		//$product_name = $item_data['name'];
		//$product_id = $item_data['product_id'];
		//$variation_id = $item_data['variation_id'];
		//$quantity = $item_data['quantity'];
		//$tax_class = $item_data['tax_class'];
		//$line_subtotal = $item_data['subtotal'];
		//$line_subtotal_tax = $item_data['subtotal_tax'];
		//$line_total = $item_data['total'];
		//$line_total_tax = $item_data['total_tax'];
	
		$pixelstat_insert   = $wpdb->insert($table_name_data, 
											array( 
												'order_id'   => $order_id, 
												'product_id' => $product_id,
												'ip'         => $order_ip,
												'pixel'      => 'fdsqfdsqfdsqfd',
												'status'     => 0
											), 
											array( 
												'%s', '%s', '%s', '%s', '%d'
											)
										);
	
	}
}
// ----------------------------------------------------------------------
// ----------------------------------------------------------------------
// ----------------------------------------------------------------------

?>